==> ejc-probuilddiary-impl-3.0.0-20220920.032121-18-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonSafetyEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-安全活动情况（安全员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_safety")
public class PersonSafetyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="safety_id")
    private Long safetyId; // 工作类别id
    @TableField(value="safety_name")
    private String safetyName; // 工作类别名称
    @TableField(value="safety_code")
    private String safetyCode; // 工作类别编码
    @TableField(value="safety_memo")
    private String safetyMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型
    @TableField(value = "log_number")
    private String logNumber;//日志 数目

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getSafetyId() {
        return safetyId;
    }

    public void setSafetyId(Long safetyId) {
        this.safetyId = safetyId;
    }
    public String getSafetyName() {
        return safetyName;
    }

    public void setSafetyName(String safetyName) {
        this.safetyName = safetyName;
    }
    public String getSafetyCode() {
        return safetyCode;
    }

    public void setSafetyCode(String safetyCode) {
        this.safetyCode = safetyCode;
    }
    public String getSafetyMemo() {
        return safetyMemo;
    }

    public void setSafetyMemo(String safetyMemo) {
        this.safetyMemo = safetyMemo;
    }
    
}

==> ejc-probuilddiary-impl-3.0.0-20250529.110337-158-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonSafetyEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-安全活动情况（安全员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_safety")
public class PersonSafetyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="safety_id")
    private Long safetyId; // 工作类别id
    @TableField(value="safety_name")
    private String safetyName; // 工作类别名称
    @TableField(value="safety_code")
    private String safetyCode; // 工作类别编码
    @TableField(value="safety_memo")
    private String safetyMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型
    @TableField(value = "log_number")
    private String logNumber;//日志 数目
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getSafetyId() {
        return safetyId;
    }

    public void setSafetyId(Long safetyId) {
        this.safetyId = safetyId;
    }
    public String getSafetyName() {
        return safetyName;
    }

    public void setSafetyName(String safetyName) {
        this.safetyName = safetyName;
    }
    public String getSafetyCode() {
        return safetyCode;
    }

    public void setSafetyCode(String safetyCode) {
        this.safetyCode = safetyCode;
    }
    public String getSafetyMemo() {
        return safetyMemo;
    }

    public void setSafetyMemo(String safetyMemo) {
        this.safetyMemo = safetyMemo;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
}
